/*
 * Copyright © 2011 Nokia Corporation. All rights reserved.
 * Nokia and Nokia Connecting People are registered trademarks of Nokia Corporation. 
 * Oracle and Java are trademarks or registered trademarks of Oracle and/or its
 * affiliates. Other product and company names mentioned herein may be trademarks
 * or trade names of their respective owners. 
 * See LICENSE.TXT for license information.
 */
package com.nokia.example.attractions.location;

/**
 * Abstract location finder.
 */
public abstract class LocationFinder {

    /**
     * Start finding location.
     */
    public abstract void start();

    /**
     * Stop finding location.
     */
    public abstract void quit();
    protected Listener listener;

    /**
     * Interface for notifying when the location has changed.
     */
    public interface Listener {

        void newLocation(double lat, double lon, int accuracy);
    }

    /**
     * Creates a location finder based on the capabilities the device.
     * @param listener
     * @return 
     */
    public static LocationFinder getFinder(Listener listener) {
        if (listener == null) {
            throw new NullPointerException("listener not defined");
        }

        LocationFinder finder = null;
        try {
            // this will throw an exception if JSR-179 is missing
            Class.forName("javax.microedition.location.Location");

            if (supportsCellId()) {
                Class c =
                    Class.forName(
                    "com.nokia.example.attractions.location.CellIdLocationFinder");
                finder = (LocationFinder) (c.newInstance());
                finder.listener = listener;
            }
            else {
                Class c =
                    Class.forName(
                    "com.nokia.example.attractions.location.GpsLocationFinder");
                finder = (LocationFinder) (c.newInstance());
                finder.listener = listener;
            }
        }
        catch (Exception e) {
        }
        return finder;
    }

    private static boolean supportsCellId() {
        if (!"available".equals(System.getProperty(
            "com.nokia.mid.networkavailability"))) {
            return false;
        }
        try {
            Class.forName("com.nokia.mid.location.LocationUtil");
            return true;
        }
        catch (Exception e) {
            return false;
        }
    }
}
