/*
 * Copyright © 2011 Nokia Corporation. All rights reserved.
 * Nokia and Nokia Connecting People are registered trademarks of Nokia Corporation. 
 * Oracle and Java are trademarks or registered trademarks of Oracle and/or its
 * affiliates. Other product and company names mentioned herein may be trademarks
 * or trade names of their respective owners. 
 * See LICENSE.TXT for license information.
 */
package com.nokia.example.attractions.map;

import com.nokia.example.attractions.Main;
import com.nokia.example.attractions.utils.KeyCodes;
import com.nokia.example.attractions.Visual;
import com.nokia.maps.map.EventListener;
import com.nokia.maps.map.MapComponent;
import com.nokia.maps.map.MapDisplay;
import com.nokia.maps.map.Point;
import javax.microedition.lcdui.Graphics;

/**
 * This class draws the back button on top of the map and listens for
 * when the user presses said button.
 */
public final class TouristMapOverlays
    implements MapComponent, EventListener {

    private MapDisplay mapDisplay;
    private int height, width;
    private String buttonLabel = "Back";
    private Point endDragPoint = new Point(0, 0);
    private Point startDragPoint = new Point(0, 0);

    /**
     * @see MapComponent#getId() 
     */
    public final String getId() {
        return "overlays";
    }

    /**
     * @see MapComponent#getVersion() 
     */
    public final String getVersion() {
        return "0.1";
    }

    /**
     * @see MapComponent#attach(com.nokia.maps.map.MapDisplay) 
     */
    public final void attach(MapDisplay md) {
        mapDisplay = md;
        height = mapDisplay.getHeight();
        width = mapDisplay.getWidth();
    }

    /**
     * @see MapComponent#detach(com.nokia.maps.map.MapDisplay) 
     */
    public final void detach(MapDisplay md) {
        mapDisplay = null;
    }

    /**
     * @see MapComponent#paint(javax.microedition.lcdui.Graphics) 
     */
    public final void paint(Graphics g) {
        g.setFont(Visual.SOFTKEY_FONT);
        g.setColor(Visual.SOFTKEY_TEXT_COLOR);
        g.drawString(buttonLabel, width - Visual.SOFTKEY_MARGIN, height
            - Visual.SOFTKEY_MARGIN, Graphics.RIGHT | Graphics.BOTTOM);
    }

    /**
     * @see MapComponent#mapUpdated(boolean) 
     */
    public final void mapUpdated(boolean bln) {
    }

    /**
     * @see MapComponent#getEventListener() 
     */
    public final EventListener getEventListener() {
        return this;
    }

    /**
     * @see EventListener#keyPressed(int, int) 
     */
    public final boolean keyPressed(int keyCode, int i) {
        if (keyCode == KeyCodes.RIGHT_SOFTKEY) {
            Main.getInstance().closeMap();
            return true;
        }
        return false;
    }

    /**
     * @see EventListener#keyReleased(int, int) 
     */
    public final boolean keyReleased(int i, int i1) {
        return false;
    }

    /**
     * @see EventListener#keyRepeated(int, int, int) 
     */
    public final boolean keyRepeated(int i, int i1, int i2) {
        return false;
    }

    /**
     * @see EventListener#pointerDragged(int, int) 
     */
    public final boolean pointerDragged(int newx, int newy) {
        endDragPoint.setX(newx);
        endDragPoint.setY(newy);
        this.mapDisplay.pan(endDragPoint, this.startDragPoint);
        startDragPoint.setX(newx);
        startDragPoint.setY(newy);
        return true;
    }

    /**
     * @see EventListener#pointerPressed(int, int) 
     */
    public final boolean pointerPressed(int x, int y) {
        startDragPoint.setX(x);
        startDragPoint.setY(y);
        //Check the coordinates to see if the button was pressed
        if (x > width / 2 && y > (height - 2 * Visual.SOFTKEY_FONT.getHeight())) {
            Main.getInstance().closeMap();
        }
        return false;
    }

    /**
     * @see EventListener#pointerReleased(int, int) 
     */
    public final boolean pointerReleased(int i, int i1) {
        return false;
    }
}
